@@ -38,7 +38,7 @@ import subprocess
 
 # python package version
 # should match r"^__version__ = '(?P<version>[^']+)'$" for setup.py
-__version__ = '0.3.1'
+__version__ = '0.4.0'
 
 
 def which(program):
@@ -153,12 +153,13 @@ class Vagrant(object):
         '''
         self._run_vagrant_command('init', box_name, box_url)
 
-    def up(self, no_provision=False, vm_name=None):
+    def up(self, no_provision=False, provider=None, vm_name=None):
         '''
         Launch the Vagrant box.
         '''
         no_provision_arg = '--no-provision' if no_provision else None
-        self._run_vagrant_command('up', vm_name, no_provision_arg)
+        provider_arg = '--provider=%s' % provider if provider else None
+        self._run_vagrant_command('up', vm_name, no_provision_arg, provider_arg)
         try:
             self.conf(vm_name=vm_name)  # cache configuration
         except subprocess.CalledProcessError:
@@ -192,10 +193,10 @@ class Vagrant(object):
 
     def status(self, vm_name=None):
         '''
-        Returns the status of a Vagrant box or a dictionary mapping vm names
-        to statuses.  Statuses are RUNNING, POWEROFF, SAVED and NOT_CREATED,
-        corresponding to vagrant up, halt, suspend, and destroy, respectively.
-        
+        Returns a dictionary mapping Vagrant box names to statuses.  Statuses
+        are RUNNING, POWEROFF, SAVED and NOT_CREATED, corresponding to vagrant
+        up, halt, suspend, and destroy, respectively.
+
         In a single-VM environment or when the vm_name parameter is used in
         a multi-VM environment, a status string is returned:
 
@@ -265,15 +266,7 @@ class Vagrant(object):
             elif state == 3 and not line.strip():
                 break
 
-        if len(statuses) == 0:
-            # no status found
-            return None
-        elif len(statuses) == 1:
-            # single-VM environment or multi-VM env and vm_name arg given.
-            return statuses.values()[0]
-        else:
-            # multi-VM environment
-            return statuses
+        return statuses
 
     def conf(self, ssh_config=None, vm_name=None):
         '''
